@@ -12,7 +12,7 @@ REGEX = r"([A-Za-z]+-[0-9]+)"
 class YoutrackHandler:
     def __init__(self, config, tokens):
         headers = {"Accept": "application/json", "Content-Type": "application/json"}
-        self._base_url = config.youtrack["url"]
+        self._base_url = config.youtrack["url"] + "/"
         self._issue_url = urljoin(self._base_url, "issue/")
         self._client = BaseUrlSession(base_url=urljoin(self._base_url, "api/"))
         self._client.headers = headers
